@@ -490,6 +490,16 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				$html = $this->gInstance->getTextConvManager()->convToContentMacro($html);
 				$html2 = $this->gInstance->getTextConvManager()->convToContentMacro($html2);
 				
+				// 記事に含まれるすべての画像のパスを取得
+				if ((($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang) &&		// // 多言語対応の場合はデフォルト言語が選択されている場合のみ処理を行う
+					$status == 2){		// 記事公開の場合のみアイキャッチ画像を作成
+					$imagePathArray = $this->gInstance->getImageManager()->getSiteImagePath($html);
+					$imagePathArray2 = $this->gInstance->getImageManager()->getSiteImagePath($html2);
+					$imagePathArray = array_unique(array_merge($imagePathArray, $imagePathArray2));
+				} else {
+					$imagePathArray = array();
+				}
+				
 				// 追加パラメータ
 				$otherParams = array(	'be_description'		=> $desc,		// 簡易説明
 										'be_meta_description'	=> $metaDesc,		// ページ要約(METAタグ)
@@ -501,10 +511,10 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 
 				// 記事データを追加
 				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){		// 多言語でデフォルト言語、または単一言語のとき
-					$ret = self::$_mainDb->addEntryItem($nextEntryId * (-1)/*次のコンテンツIDのチェック*/, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
+					$ret = self::$_mainDb->addEntryItem($nextEntryId * (-1)/*次のコンテンツIDのチェック*/, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $imagePathArray, $this->blogId, 
 													$this->_userId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $otherParams);
 				} else {
-					$ret = self::$_mainDb->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
+					$ret = self::$_mainDb->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $imagePathArray, $this->blogId, 
 													$this->_userId, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $otherParams);
 				}
 				if ($ret){
@@ -623,6 +633,16 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				$html = $this->gInstance->getTextConvManager()->convToContentMacro($html);
 				$html2 = $this->gInstance->getTextConvManager()->convToContentMacro($html2);
 				
+				// 記事に含まれるすべての画像のパスを取得
+				if ((($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang) &&		// // 多言語対応の場合はデフォルト言語が選択されている場合のみ処理を行う
+					$status == 2){		// 記事公開の場合のみアイキャッチ画像を作成
+					$imagePathArray = $this->gInstance->getImageManager()->getSiteImagePath($html);
+					$imagePathArray2 = $this->gInstance->getImageManager()->getSiteImagePath($html2);
+					$imagePathArray = array_unique(array_merge($imagePathArray, $imagePathArray2));
+				} else {
+					$imagePathArray = array();
+				}
+				
 				// 追加パラメータ
 				$otherParams = array(	'be_description'		=> $desc,		// 簡易説明
 										'be_meta_description'	=> $metaDesc,		// ページ要約(METAタグ)
@@ -641,7 +661,7 @@ class blog_mainEntryWidgetContainer extends blog_mainBaseWidgetContainer
 				}
 			
 				// 記事データを更新
-				$ret = self::$_mainDb->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
+				$ret = self::$_mainDb->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, $imagePathArray, $this->blogId, 
 													''/*投稿者そのまま*/, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $oldRecord, $otherParams);
 /*				if ($ret){
 					// コンテンツに画像がなくなった場合は、サムネールを削除
